import request from '@/utils/request'

// 查询整改组内成员信息列表
export function listInfo(query) {
  return request({
    url: '/danger/member/list',
    method: 'get',
    params: query
  })
}

// 查询整改组内成员信息详细
export function getInfo(memberId) {
  return request({
    url: '/danger/member/' + memberId,
    method: 'get'
  })
}

// 新增整改组内成员信息
export function addInfo(data) {
  return request({
    url: '/danger/member',
    method: 'post',
    data: data
  })
}

// 修改整改组内成员信息
export function updateInfo(data) {
  return request({
    url: '/danger/member',
    method: 'put',
    data: data
  })
}

// 删除整改组内成员信息
export function delInfo(memberId) {
  return request({
    url: '/danger/member/' + memberId,
    method: 'delete'
  })
}

// 导出整改组内成员信息
export function exportInfo(query) {
  return request({
    url: '/danger/member/export',
    method: 'get',
    params: query
  })
}

//获取整改人员信息
export function selectRectifyUserByPostCode(data) {
  return request({
    url: '/danger/member/selectRectifyUserByPostCode',
    method: 'post',
    data: data
  })
}
